placeboNonResponder: Example of helper function for determining placebo nonresponse
Description
The input to SPCDcontinuous requires a logical field which says that the patient was not a placebo responder in the the first phase of the study. Usually this is determined by whether their outcome was greater than a specified value but could have other criteria. This an example program which specifies non-responders as patients whose first phase results were greater than a constant.
Usage
placeboNonResponder(data, ID = "ID", k = 0)
Arguments
data
The data file to use to determine non-response.
ID
Text field indicating the name of the Patient ID variable.
k
A numeric constant. A patient is a non-responder if their change from baseline was greater than k.
Value
A new data frame with a variable named nonResponder.
References
Chen, Y. F., Yang, Y., Hung, H. J., & Wang, S. J. (2011). Evaluation of performance of some enrichment designs dealing with high placebo response in psychiatric clinical trials. Contemporary clinical trials, 32,4, 592-604.